yakumo.keystone.v3.service

Package yakumo :: Package keystone :: Package v3 :: Module service |
[hide private]
[frames] | no frames]

# Module service

source code

Resource class and its manager for services in Identity V3 API

Classes | [hide private]
| Resource resource class for services on Identity V3 API
| Manager manager class for services on Identity V3 API

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass obj`...``
| __package__ = ``'``yakumo.keystone.v3``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('id', 'id', <yakumo.mapper.NoopClass object at 0x7f133076f290>),
       ('name', 'name', <yakumo.mapper.NoopClass object at 0x7f133076f290>),
       ('type', 'type', <yakumo.mapper.NoopClass object at 0x7f133076f290>),
       ('description',
        'description',
        <yakumo.mapper.NoopClass object at 0x7f133076f290>),
       ('is_enabled',
        'enabled',
      ...